<?php

/**
 * @file
 * Definition of WoW\RemoteEntityControllerInterface.
 */

interface WoWRemoteEntityControllerInterface
  extends EntityAPIControllerInterface {

  /**
   * Set the wow entity refresh method for this controller.
   *
   * @param string $method
   *   The method to set.
   */
  public function refreshMethod($method);

  /**
   * Fetch a remote resource from the service.
   *
   * @param WoWRemoteEntity $entity
   *   The entity to fetch.
   * @param array $query
   *   (Optional) An array of query key/value-pairs (without any URL-encoding) to
   *   append to the URL.
   *   - locale: You can specify your own locale here.
   *     It it the responsibility of the caller to pass a valid locale.
   *     @see wow_api_locale()
   * @param array $options
   *   (Optional) An array that can have one or more of the following elements:
   *   - headers: An array containing request headers to send as name/value pairs.
   *   - method: A string containing the request method. Defaults to 'GET'.
   *   - data: A string containing the request body, formatted as
   *     'param=value&param=value&...'. Defaults to NULL.
   *   - max_redirects: An integer representing how many times a redirect
   *     may be followed. Defaults to 3.
   *   - timeout: A float representing the maximum number of seconds the function
   *     call may take. The default is 30 seconds. If a timeout occurs, the error
   *     code is set to the HTTP_REQUEST_TIMEOUT constant.
   *   - context: A context resource created with stream_context_create().
   *
   * @return WoWRemoteEntity $entity
   *   The entity reference.
   */
  public function fetch($entity, array $query = array(), array $options = array());

  /**
   * Process an HttpResponse object from the service.
   *
   * @param WoWRemoteEntity $entity
   *   The entity which is the subject.
   * @param WoWHttpResponse $response
   *   The response object to process.
   *
   * @return WoWRemoteEntity $entity
   *   The entity reference.
   */
  public function process($entity, $response);
}
